Struct thumbor::endpoint::Endpoint

source ·
pub struct Endpoint { /* private fields */ }
An endpoint is a representation of a Thumbor image URL.

Usage

EndpointBuilder is used to create an Endpoint instance.

You can then use the Endpoint::to_url method to generate the URL, or the Endpoint::to_path method to get the path (without the server origin).

The format of the image URI depends heavily on the image loader you are using. Thumbor comes pre-packaged with an HTTP loader and a Filesystem loader.

  • If you use the HTTP loader, the URI corresponds to the image complete URI.
  • If you use the Filesystem loader, the URI corresponds to the path of the image from the images root.

Implementations

source

impl Endpoint

source

pub fn to_path(&self, image_uri: &str) -> String

use thumbor::Server;

let server = Server::new_unsafe("http://localhost:8888");
let endpoint = server.endpoint_builder().build();
let path = endpoint.to_path("path/to/my/image.jpg");

assert_eq!(path, "/unsafe/path/to/my/image.jpg");
source

pub fn to_url(&self, image_uri: &str) -> String

use thumbor::Server;

let server = Server::new_unsafe("http://localhost:8888");
let endpoint = server.endpoint_builder().build();
let path = endpoint.to_url("path/to/my/image.jpg");

assert_eq!(path, "http://localhost:8888/unsafe/path/to/my/image.jpg");
source

impl Endpoint

source

pub fn with_server(server: Server) -> EndpointBuilder

Create an instance of Endpoint using the builder syntax